Change log
==========

v0.3.0
------

- Improvement: made ``use_peeringdb`` an attribute of devices' declaration.

- Improvement: some fixes.

Also, the tool can be used as a library now.

v0.2.0
------

- New: IP based filters extended to the use of prefixes too.

- New: ``--use-peeringdb`` argument to fetch missing peers' ASNs from PeeringDB (e.g. in case of multi-lateral peering at IXPs).

v0.1.0
------

First release.
